PulledPork3
===========

Pulled Pork for Snort3 rule management (Everything is better smoked)

Find us on Libera.Chat (IRC) [`#pulledpork`](https://libera.chat/guides/connect)

Copyright (C) 2021 Noah Dietrich and the PulledPork Team!

## Warning
This is a placeholder package for PulledPork3, and sholuld not be used at this time.
Once PulledPork reaches Beta status, we will update this package so you can install PulledPokrk3 through PIP.